
/* Generated data (by glib-mkenums) */

#ifndef __FLATPAK_ENUM_TYPES_H__
#define __FLATPAK_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "lib/flatpak-error.h" */
FLATPAK_EXTERN GType flatpak_error_get_type (void) G_GNUC_CONST;
#define FLATPAK_TYPE_ERROR (flatpak_error_get_type ())

/* enumerations from "lib/flatpak-installation.h" */
FLATPAK_EXTERN GType flatpak_update_flags_get_type (void) G_GNUC_CONST;
#define FLATPAK_TYPE_UPDATE_FLAGS (flatpak_update_flags_get_type ())
FLATPAK_EXTERN GType flatpak_install_flags_get_type (void) G_GNUC_CONST;
#define FLATPAK_TYPE_INSTALL_FLAGS (flatpak_install_flags_get_type ())
FLATPAK_EXTERN GType flatpak_storage_type_get_type (void) G_GNUC_CONST;
#define FLATPAK_TYPE_STORAGE_TYPE (flatpak_storage_type_get_type ())

/* enumerations from "lib/flatpak-ref.h" */
FLATPAK_EXTERN GType flatpak_ref_kind_get_type (void) G_GNUC_CONST;
#define FLATPAK_TYPE_REF_KIND (flatpak_ref_kind_get_type ())
G_END_DECLS

#endif /* __GIO_ENUM_TYPES_H__ */

/* Generated data ends here */

